<?php
namespace Aws\CloudWatchLogs\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon CloudWatch Logs service.
 */
class CloudWatchLogsException extends AwsException {}
